NetworkMode

Struct NetworkMode 

#[repr(C)]
pub struct NetworkMode {
Show 19 fields pub state: NetworkState, pub hw_address_size: u32, pub media_header_size: u32, pub max_packet_size: u32, pub nv_ram_size: u32, pub nv_ram_access_size: u32, pub receive_filter_mask: u32, pub receive_filter_setting: u32, pub max_mcast_filter_count: u32, pub mcast_filter_count: u32, pub mcast_filter: [MacAddress; 16], pub current_address: MacAddress, pub broadcast_address: MacAddress, pub permanent_address: MacAddress, pub if_type: u8, pub mac_address_changeable: Boolean, pub multiple_tx_supported: Boolean, pub media_present_supported: Boolean, pub media_present: Boolean,
}
Information about the current configuration of an interface obtained by the SimpleNetworkProtocol.

Fields

state: NetworkState

Reports the current state of the network interface

hw_address_size: u32

The size of the network interface’s hardware address in bytes

media_header_size: u32

The size of the network interface’s media header in bytes

max_packet_size: u32

The maximum size of the packets supported by the network interface in bytes

nv_ram_size: u32

The size of the NVRAM device attached to the network interface in bytes

nv_ram_access_size: u32

The size that must be used for all NVRAM reads and writes

receive_filter_mask: u32

The multicast receive filter settings supported by the network interface

receive_filter_setting: u32

The current multicast receive filter settings

max_mcast_filter_count: u32

The maximum number of multicast address receive filters supported by the driver

mcast_filter_count: u32

The current number of multicast address receive filters

mcast_filter: [MacAddress; 16]

The array containing the addresses of the current multicast address receive filters

current_address: MacAddress

The current hardware MAC address for the network interface

broadcast_address: MacAddress

The current hardware MAC address for broadcast packets

permanent_address: MacAddress

The permanent hardware MAC address for the network interface

if_type: u8

The interface type of the network interface

mac_address_changeable: Boolean

Tells if the MAC address can be changed

multiple_tx_supported: Boolean

Tells if the network interface can transmit more than one packet at a time

media_present_supported: Boolean

Tells if the presence of the media can be determined

media_present: Boolean

Tells if media are connected to the network interface