Struct SimpleNetworkProtocol
Source #[repr(C)]
pub struct SimpleNetworkProtocol {Show 16 fields
pub revision: u64,
pub start: unsafe extern "efiapi" fn(this: *const Self) -> Status,
pub stop: unsafe extern "efiapi" fn(this: *const Self) -> Status,
pub initialize: unsafe extern "efiapi" fn(this: *const Self, extra_receive_buffer_size: usize, extra_transmit_buffer_size: usize) -> Status,
pub reset: unsafe extern "efiapi" fn(this: *const Self, extended_verification: Boolean) -> Status,
pub shutdown: unsafe extern "efiapi" fn(this: *const Self) -> Status,
pub receive_filters: unsafe extern "efiapi" fn(this: *const Self, enable: ReceiveFlags, disable: ReceiveFlags, reset_multicast_filter: Boolean, multicast_filter_count: usize, multicast_filter: *const MacAddress) -> Status,
pub station_address: unsafe extern "efiapi" fn(this: *const Self, reset: Boolean, new: *const MacAddress) -> Status,
pub statistics: unsafe extern "efiapi" fn(this: *const Self, reset: Boolean, statistics_size: *mut usize, statistics_table: *mut NetworkStatistics) -> Status,
pub multicast_ip_to_mac: unsafe extern "efiapi" fn(this: *const Self, ipv6: Boolean, ip: *const IpAddress, mac: *mut MacAddress) -> Status,
pub non_volatile_data: unsafe extern "efiapi" fn(this: *const Self, read: Boolean, offset: usize, buffer_size: usize, buffer: *mut c_void) -> Status,
pub get_status: unsafe extern "efiapi" fn(this: *const Self, interrupt_status: *mut InterruptStatus, transmit_buffer: *mut *mut c_void) -> Status,
pub transmit: unsafe extern "efiapi" fn(this: *const Self, header_size: usize, buffer_size: usize, buffer: *const c_void, source_address: *const MacAddress, dest_address: *const MacAddress, protocol: *const u16) -> Status,
pub receive: unsafe extern "efiapi" fn(this: *const Self, header_size: *mut usize, buffer_size: *mut usize, buffer: *mut c_void, source_address: *mut MacAddress, dest_address: *mut MacAddress, protocol: *mut u16) -> Status,
pub wait_for_packet: Event,
pub mode: *mut NetworkMode,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.